==> openflowplugin-extension-nicira-0.8.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/nxm/nx/nsh/ttl/grouping/NxmNxNshTtlBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.nsh.ttl.grouping;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.Short;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link NxmNxNshTtlBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     NxmNxNshTtlBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new NxmNxNshTtlBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of NxmNxNshTtlBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see NxmNxNshTtlBuilder
 * @see Builder
 *
 */
public class NxmNxNshTtlBuilder implements Builder<NxmNxNshTtl> {

    private Short _nshTtl;


    Map<Class<? extends Augmentation<NxmNxNshTtl>>, Augmentation<NxmNxNshTtl>> augmentation = Collections.emptyMap();

    public NxmNxNshTtlBuilder() {
    }

    public NxmNxNshTtlBuilder(NxmNxNshTtl base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<NxmNxNshTtl>>, Augmentation<NxmNxNshTtl>> aug =((AugmentationHolder<NxmNxNshTtl>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._nshTtl = base.getNshTtl();
    }


    public Short getNshTtl() {
        return _nshTtl;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<NxmNxNshTtl>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    private static void checkNshTtlRange(final short value) {
        if (value >= (short)0 && value <= (short)255) {
            return;
        }
        CodeHelpers.throwInvalidRange("[[0..255]]", value);
    }
    
    public NxmNxNshTtlBuilder setNshTtl(final Short value) {
    if (value != null) {
        checkNshTtlRange(value);
        
    }
        this._nshTtl = value;
        return this;
    }
    
    public NxmNxNshTtlBuilder addAugmentation(Class<? extends Augmentation<NxmNxNshTtl>> augmentationType, Augmentation<NxmNxNshTtl> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public NxmNxNshTtlBuilder removeAugmentation(Class<? extends Augmentation<NxmNxNshTtl>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public NxmNxNshTtl build() {
        return new NxmNxNshTtlImpl(this);
    }

    private static final class NxmNxNshTtlImpl
        extends AbstractAugmentable<NxmNxNshTtl>
        implements NxmNxNshTtl {
    
        private final Short _nshTtl;
    
        NxmNxNshTtlImpl(NxmNxNshTtlBuilder base) {
            super(base.augmentation);
            this._nshTtl = base.getNshTtl();
        }
    
        @Override
        public Class<NxmNxNshTtl> getImplementedInterface() {
            return NxmNxNshTtl.class;
        }
    
        @Override
        public Short getNshTtl() {
            return _nshTtl;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nshTtl);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxmNxNshTtl.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            NxmNxNshTtl other = (NxmNxNshTtl)obj;
            if (!Objects.equals(_nshTtl, other.getNshTtl())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxmNxNshTtlImpl otherImpl = (NxmNxNshTtlImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxmNxNshTtl>>, Augmentation<NxmNxNshTtl>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxmNxNshTtl");
            CodeHelpers.appendValue(helper, "_nshTtl", _nshTtl);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}

==> openflowplugin-extension-nicira-0.9.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/nxm/nx/nsh/ttl/grouping/NxmNxNshTtlBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.nsh.ttl.grouping;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.Short;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link NxmNxNshTtlBuilder} instances.
 *
 * @see NxmNxNshTtlBuilder
 *
 */
public class NxmNxNshTtlBuilder implements Builder<NxmNxNshTtl> {

    private Short _nshTtl;


    Map<Class<? extends Augmentation<NxmNxNshTtl>>, Augmentation<NxmNxNshTtl>> augmentation = Collections.emptyMap();

    public NxmNxNshTtlBuilder() {
    }

    public NxmNxNshTtlBuilder(NxmNxNshTtl base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<NxmNxNshTtl>>, Augmentation<NxmNxNshTtl>> aug =((AugmentationHolder<NxmNxNshTtl>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._nshTtl = base.getNshTtl();
    }


    public Short getNshTtl() {
        return _nshTtl;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<NxmNxNshTtl>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    private static void checkNshTtlRange(final short value) {
        if (value >= (short)0 && value <= (short)255) {
            return;
        }
        CodeHelpers.throwInvalidRange("[[0..255]]", value);
    }
    
    public NxmNxNshTtlBuilder setNshTtl(final Short value) {
    if (value != null) {
        checkNshTtlRange(value);
        
    }
        this._nshTtl = value;
        return this;
    }
    
    public NxmNxNshTtlBuilder addAugmentation(Class<? extends Augmentation<NxmNxNshTtl>> augmentationType, Augmentation<NxmNxNshTtl> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public NxmNxNshTtlBuilder removeAugmentation(Class<? extends Augmentation<NxmNxNshTtl>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public NxmNxNshTtl build() {
        return new NxmNxNshTtlImpl(this);
    }

    private static final class NxmNxNshTtlImpl
        extends AbstractAugmentable<NxmNxNshTtl>
        implements NxmNxNshTtl {
    
        private final Short _nshTtl;
    
        NxmNxNshTtlImpl(NxmNxNshTtlBuilder base) {
            super(base.augmentation);
            this._nshTtl = base.getNshTtl();
        }
    
        @Override
        public Short getNshTtl() {
            return _nshTtl;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nshTtl);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxmNxNshTtl.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            NxmNxNshTtl other = (NxmNxNshTtl)obj;
            if (!Objects.equals(_nshTtl, other.getNshTtl())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxmNxNshTtlImpl otherImpl = (NxmNxNshTtlImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxmNxNshTtl>>, Augmentation<NxmNxNshTtl>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxmNxNshTtl");
            CodeHelpers.appendValue(helper, "_nshTtl", _nshTtl);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}
